@@ -17,12 +17,14 @@ from .utils import MaestralBackgroundTask
 
 # noinspection PyArgumentList
 class RelinkDialog(QtWidgets.QDialog):
-    """A dialog to show when Maestral's Dropbox access has expired or has been revoked."""
+    """
+    A dialog to show when Maestral's Dropbox access has expired or has been revoked.
+    """
 
-    VALID_MSG = 'Verified. Restarting Maestral...'
-    INVALID_MSG = 'Invalid token'
-    CONNECTION_ERR_MSG = 'Connection failed'
-    PLACEHOLDER_TEXT = 'Authorization token'
+    VALID_MSG = "Verified. Restarting Maestral..."
+    INVALID_MSG = "Invalid token"
+    CONNECTION_ERR_MSG = "Connection failed"
+    PLACEHOLDER_TEXT = "Authorization token"
 
     EXPIRED = 0
     REVOKED = 1
@@ -31,24 +33,31 @@ class RelinkDialog(QtWidgets.QDialog):
         super().__init__()
         uic.loadUi(RELINK_DIALOG_PATH, self)
         # noinspection PyTypeChecker
-        self.setWindowFlags(Qt.WindowStaysOnTopHint | Qt.Sheet | Qt.WindowTitleHint
-                            | Qt.CustomizeWindowHint)
+        self.setWindowFlags(
+            Qt.WindowStaysOnTopHint
+            | Qt.Sheet
+            | Qt.WindowTitleHint
+            | Qt.CustomizeWindowHint
+        )
 
         self._parent = parent
         self.mdbx = self._parent.mdbx
 
         # format text labels
         if reason is self.EXPIRED:
-            self.titleLabel.setText('Dropbox Access Expired')
+            self.titleLabel.setText("Dropbox Access Expired")
             formatted_text = self.infoLabel.text().format(
-                'has expired', self.mdbx.get_auth_url())
+                "has expired", self.mdbx.get_auth_url()
+            )
         elif reason is self.REVOKED:
-            self.titleLabel.setText('Dropbox Access Revoked')
+            self.titleLabel.setText("Dropbox Access Revoked")
             formatted_text = self.infoLabel.text().format(
-                'has been revoked', self.mdbx.get_auth_url())
+                "has been revoked", self.mdbx.get_auth_url()
+            )
         else:
-            raise ValueError('"reason" must be RelinkDialog.EXPIRED or '
-                             'RelinkDialog.REVOKED.')
+            raise ValueError(
+                '"reason" must be RelinkDialog.EXPIRED or ' "RelinkDialog.REVOKED."
+            )
         self.infoLabel.setText(formatted_text)
         self.titleLabel.setFont(get_scaled_font(bold=True))
         self.infoLabel.setFont(get_scaled_font(scaling=0.9))
@@ -85,29 +94,35 @@ class RelinkDialog(QtWidgets.QDialog):
     @QtCore.pyqtSlot(str)
     def _update_appearance(self, text):
         placeholder_text = self.lineEditAuthCode.placeholderText()
-        if text == '':
+        if text == "":
             if placeholder_text == self.PLACEHOLDER_TEXT:
                 self.pushButtonLink.setEnabled(False)
-                self.lineEditAuthCode.setStyleSheet('')
+                self.lineEditAuthCode.setStyleSheet("")
             elif placeholder_text == self.INVALID_MSG:
                 self.pushButtonLink.setEnabled(False)
-                self.lineEditAuthCode.setStyleSheet('color: rgb(205, 0, 0); font: bold;')
+                self.lineEditAuthCode.setStyleSheet(
+                    "color: rgb(205, 0, 0); font: bold;"
+                )
             elif placeholder_text == self.CONNECTION_ERR_MSG:
                 self.pushButtonLink.setEnabled(False)
-                self.lineEditAuthCode.setStyleSheet('color: rgb(205, 0, 0); font: bold;')
+                self.lineEditAuthCode.setStyleSheet(
+                    "color: rgb(205, 0, 0); font: bold;"
+                )
             elif placeholder_text == self.VALID_MSG:
                 self.pushButtonLink.setEnabled(False)
                 self.pushButtonUnlink.setEnabled(False)
                 self.pushButtonCancel.setEnabled(False)
-                self.lineEditAuthCode.setStyleSheet('color: rgb(0, 129, 0); font: bold;')
+                self.lineEditAuthCode.setStyleSheet(
+                    "color: rgb(0, 129, 0); font: bold;"
+                )
         else:
             self.pushButtonLink.setEnabled(True)
-            self.lineEditAuthCode.setStyleSheet('')
+            self.lineEditAuthCode.setStyleSheet("")
 
     @QtCore.pyqtSlot()
     def on_link_clicked(self):
         token = self.lineEditAuthCode.text()
-        if token == '':
+        if token == "":
             # this should not occur because link button will be inactivate when there
             # is no text in QLineEdit
             return
@@ -115,10 +130,7 @@ class RelinkDialog(QtWidgets.QDialog):
         self.set_ui_busy()
 
         self.auth_task = MaestralBackgroundTask(
-            parent=self,
-            config_name=self.mdbx.config_name,
-            target='link',
-            args=(token,)
+            parent=self, config_name=self.mdbx.config_name, target="link", args=(token,)
         )
         self.auth_task.sig_done.connect(self.on_link_done)
 
@@ -136,7 +148,7 @@ class RelinkDialog(QtWidgets.QDialog):
             self.lineEditAuthCode.setPlaceholderText(self.CONNECTION_ERR_MSG)
             self.set_ui_idle()
 
-        self.lineEditAuthCode.setText('')
+        self.lineEditAuthCode.setText("")
 
     def set_ui_busy(self):
         self.progressIndicator.startAnimation()
